@@ -71,7 +71,7 @@
     });
   });
 
-  app.constant('allVariantTypes', ['android', 'ios', 'windows_mpns', 'windows_wns', 'simplePush', 'adm']);
+  app.constant('allVariantTypes', ['android', 'ios', 'windows_wns', 'adm']);
 
   app.value('allowCreateVariant', function( app, variantType ) {
     return true;
@@ -132,6 +132,7 @@ angular.module('upsConsole')
       {path: '/wizard/send-push-notification',  component: 'wizard04SendPushNotification'},
       {path: '/wizard/setup-sender',  component: 'wizard05SetupSender'},
       {path: '/wizard/done',          component: 'wizard06Done'},
+      {path: '/app/:app/:tab/:variant', component: 'appDetail'},
       {path: '/app/:app/:tab',        component: 'appDetail'},
       {path: '/links-check',          component: 'linksCheck'},
     ]);
@@ -153,7 +154,7 @@ angular.module('upsConsole')
             $log.warn( 'Navigation failure: ' + path );
           }
         );
-      }, 500);
+      }, 100);
     });
   });
 
@@ -176,7 +177,7 @@ angular.module('upsConsole')
 'use strict';
 
 angular.module('upsConsole')
-  .controller('AppController', function ( $rootScope, $scope, Auth, $http, $interval, $timeout, $log, appConfig, dashboardEndpoint ) {
+  .controller('AppController', function ( $rootScope, $scope, $location, Auth, $http, $interval, $timeout, $log, appConfig, dashboardEndpoint, $$rootRouter ) {
 
     var self = this;
 
@@ -185,11 +186,21 @@ angular.module('upsConsole')
 
     //Retrieve the current logged in username
     function getUsername() {
-      return Auth.keycloak.idTokenParsed.preferred_username;
+      if (Auth && Auth.keycloak) {
+        $rootScope.showUserDropdown = true;
+        return Auth.keycloak.idTokenParsed.preferred_username;
+      } else {
+        $rootScope.showUserDropdown = false;
+        return 'dummy';
+      }
     }
+
     this.username = getUsername();
     $scope.$watch(getUsername, function( newValue ) {
       self.username = newValue;
+      // After the user is resolved, redirect to the URL passed
+      // to the browser
+      $$rootRouter.navigate($location.url());
     });
 
     this.logout = function() {
@@ -197,7 +208,7 @@ angular.module('upsConsole')
     };
 
     this.goToAccountManagement = function() {
-      window.location = Auth.keycloak.authServerUrl + '/realms/aerogear/account?referrer=unified-push-server-js';
+      window.location = Auth.keycloak.authServerUrl + '/realms/' + Auth.keycloak.realm + '/account?referrer=unified-push-server-js';
     };
 
     this.havePendingRequests = function() {
@@ -229,11 +240,12 @@ angular.module('upsConsole')
     }
     updateWarnings();
 
-    var updateWarningsInterval = $interval(updateWarnings, 30000);
-    $scope.$on('$destroy', function() {
-      $log.debug('cancelling updateWarnings interval');
-      $interval.cancel( updateWarningsInterval );
-    });
+    // For AGPUSH-1895: temporarrly we disable the polling
+    // var updateWarningsInterval = $interval(updateWarnings, 30000);
+    // $scope.$on('$destroy', function() {
+    //   $log.debug('cancelling updateWarnings interval');
+    //   $interval.cancel( updateWarningsInterval );
+    // });
     $scope.$on('upsNotificationSent', function() {
       var timer1 = $timeout(updateWarnings, 1500);
       var timer2 = $timeout(updateWarnings, 5000);
@@ -250,56 +262,61 @@ angular.module('upsConsole')
 'use strict';
 
 angular.module('upsConsole')
-  .controller('IdleController', function(Keepalive, Idle, $rootScope, $scope, $log, appConfig, Auth) {
+  .controller('IdleController', function (Keepalive, Idle, $rootScope, $scope, $log, appConfig, Auth) {
 
     var self = this;
 
     self.config = appConfig;
+
+    // No need for idling when no authentication is used
+    if (Auth && Auth.keycloak) {
+      Idle.watch();
+    }
+
     /**
      * idle service, keepalive, auth token refresh
      */
-    Idle.watch();
     self.idleCountdown = appConfig.idleWarningDuration + 1;
-    $rootScope.$on('KeepaliveResponse', function() {
-      Auth.keycloak.updateToken(45).success(function(refreshed) {
+    $rootScope.$on('KeepaliveResponse', function () {
+      Auth.keycloak.updateToken(45).success(function (refreshed) {
         if (refreshed) {
           $log.debug('token was successfully refreshed');
         } else {
           $log.debug('token is still valid');
         }
-      }).error(function() {
+      }).error(function () {
         $log.debug('failed to refresh the token, or the session has expired');
       });
     });
 
-    $rootScope.$on('IdleStart', function() {
+    $rootScope.$on('IdleStart', function () {
       $log.debug('idleStart');
 
     });
-    $rootScope.$on('IdleWarn', function() {
+    $rootScope.$on('IdleWarn', function () {
       $log.debug('idleWarn');
-      $scope.$apply(function() {
+      $scope.$apply(function () {
         self.idleCountdown = self.idleCountdown - 1;
       });
     });
-    $rootScope.$on('IdleEnd', function() {
+    $rootScope.$on('IdleEnd', function () {
       $log.debug('idleEnd');
-      $scope.$apply(function() {
+      $scope.$apply(function () {
         self.idleCountdown = appConfig.idleWarningDuration + 1;
       });
 
     });
-    $rootScope.$on('IdleTimeout', function() {
+    $rootScope.$on('IdleTimeout', function () {
       $log.debug('idleTimeout');
       Auth.logout();
     });
   })
 
-  .config( function( KeepaliveProvider, IdleProvider, appConfigProvider ) {
+  .config(function (KeepaliveProvider, IdleProvider, appConfigProvider) {
     var appConfig = appConfigProvider.$get();
-    IdleProvider.idle( appConfig.idleDuration );
-    IdleProvider.timeout( appConfig.idleWarningDuration );
-    KeepaliveProvider.interval( appConfig.keepaliveInterval );
+    IdleProvider.idle(appConfig.idleDuration);
+    IdleProvider.timeout(appConfig.idleWarningDuration);
+    KeepaliveProvider.interval(appConfig.keepaliveInterval);
   });
 
 angular.module('upsConsole')
@@ -368,7 +385,7 @@ angular.module('upsConsole')
               .then(function() {
                 $modalInstance.close();
                 if (self.totalItems < 1) {
-                  $rootScope.$broadcast('upsNavigate', '/welcome');
+                  $router.parent.navigate('/welcome');
                 }
               });
           };
@@ -400,9 +417,7 @@ angular.module('upsConsole')
     this.config = {
       android: {},
       ios: {},
-      simplePush : {},
       windows_wns: {},
-      windows_mpns: {},
       adm: {}
     };
 
@@ -452,12 +467,12 @@ angular.module('upsConsole')
       });
       applicationsEndpoint.bootstrap({}, formData)
         .then(function( app ) {
-          Notifications.success('Application ' + app.name + ' successfully created');
+          Notifications.success('Push notification support enabled for ' + app.name);
           $rootScope.$broadcast('upsUpdateStats');
           $rootScope.$broadcast('upsNavigate', '/app/' + app.pushApplicationID + '/variants');
         })
         .catch(function() {
-          Notifications.error('Failed to create application ' + self.application.name);
+          Notifications.error('Failed to enable Push notification support for ' + self.application.name);
         });
     };
 
@@ -468,79 +483,89 @@ angular.module('upsConsole')
   });
 
 angular.module('upsConsole')
-  .controller('AppDetailController', function( $rootScope, $q, $routeParams, $modal, applicationsEndpoint, messageSenderEndpoint, metricsEndpoint, ContextProvider, Notifications ) {
+  .controller('AppDetailController', function ($rootScope, $q, $routeParams, $modal, applicationsEndpoint, messageSenderEndpoint, metricsEndpoint, ContextProvider, Notifications) {
 
     var self = this;
 
     this.app = null; // is retrieved in canActivate
     this.notifications = null; // is retrieved in canActivate
     this.tab = $routeParams.tab;
+    this.selectedVariant = $routeParams.variant;
 
     this.contextPath = ContextProvider.contextPath();
 
-    this.canActivate = function() {
+    this.canActivate = function () {
       return $q.all([
         applicationsEndpoint.getWithMetrics({appId: $routeParams.app})
-          .then(function( app ) {
+          .then(function (app) {
+
+            // Expand the variant if an ID is passed in the URL
+            if (self.selectedVariant && app.variants) {
+              app.variants.forEach(function (variant) {
+                variant.$toggled = self.selectedVariant === variant.variantID;
+              });
+            }
+
             self.app = app;
-            if ( !app.variants.length ) {
+            if (!app.variants.length) {
               self.tab = 'variants';
             }
           }),
         metricsEndpoint.fetchApplicationMetrics($routeParams.app, null, 1)
-          .then(function( data ) {
+          .then(function (data) {
             self.notifications = data.pushMetrics;
           })
       ]);
     };
 
-    this.sendNotification = function() {
+    this.sendNotification = function () {
       $modal.open({
         templateUrl: 'dialogs/send-push-notification.html',
-        controller: function( $scope, $modalInstance ) {
+        controller: function ($scope, $modalInstance) {
 
           $scope.app = self.app;
 
           // default message
           $scope.pushData = {
-            
+
             'message': {
               'sound': 'default',
               'alert': '',
-              'priority':'normal',
+              'priority': 'normal',
               'simple-push': 'version=' + new Date().getTime()
             },
-            'criteria' : {}
+            'criteria': {}
           };
 
-          $scope.send = function() {
+          $scope.send = function () {
             if ($scope.selectedVariants && $scope.selectedVariants.length > 0) {
               $scope.pushData.criteria.variants = $scope.selectedVariants;
             }
-            if($scope.aliases) {
+            if ($scope.aliases) {
               $scope.pushData.criteria.alias = $scope.aliases.split(',');
             }
-            if($scope.deviceTypes) {
+            if ($scope.deviceTypes) {
               $scope.pushData.criteria.deviceType = $scope.deviceTypes.split(',');
             }
-            if($scope.categories) {
+            if ($scope.categories) {
               $scope.pushData.criteria.categories = $scope.categories.split(',');
             }
 
-            messageSenderEndpoint( self.app.pushApplicationID, self.app.masterSecret ).send({}, $scope.pushData)
-              .then(function() {
+            messageSenderEndpoint(self.app.pushApplicationID, self.app.masterSecret)
+              .send({}, $scope.pushData)
+              .then(function () {
                 self.app.$messageCount += 1;
-                self.notifications.unshift({ submitDate: new Date().getTime() });
+                self.notifications.unshift({submitDate: new Date().getTime()});
                 $modalInstance.close();
                 $rootScope.$broadcast('upsNotificationSent', $scope.pushData, $scope.app);
                 Notifications.success('Notification was successfully sent');
               })
-              .catch(function() {
+              .catch(function () {
                 Notifications.error('Failed to sent notification');
               });
           };
 
-          $scope.cancel = function() {
+          $scope.cancel = function () {
             $modalInstance.dismiss();
           };
         }
@@ -596,7 +621,6 @@ angular.module('upsConsole')
           var variantType = variantList[type] = variantList[type] || [];
           variantType.push(variant);
           variantType.$deviceCount = (variantType.$deviceCount  || 0) + (variant.$deviceCount || 0);
-          variantType.$messageCount = (variantType.$messageCount  || 0) + (variant.$messageCount || 0);
           return variantList;
         }, {});
     }
@@ -613,8 +637,8 @@ angular.module('upsConsole')
     this.add = function() {
       return variantModal.add( this.app )
         .then(function( variant ) {
+
           variant.$deviceCount = 0;
-          variant.$messageCount = 0;
           self.app.variants.push( variant );
           variant.$toggled = true;
           self.byType = splitByType( self.app.variants );
@@ -838,6 +862,11 @@ angular.module('upsConsole')
 
     var self = this;
 
+    this.TOOLTIP_TARGETS = "Targeted devices or topics for Android/Firebase";
+    this.TOOLTIP_OPENED = "Number of users that launched the mobile app by using the push notification";
+    this.TOOLTIP_SUCCESS = "Payload submitted to 3rd party push network for further processing";
+    this.TOOLTIP_FAIL = "Could not submit payload to 3rd party";
+
     this.app = $scope.$parent.$parent.appDetail.app;
     this.metrics = [];
     this.totalCount;
@@ -876,9 +905,6 @@ angular.module('upsConsole')
               console.log('failed to parse metric');
               metric.$message = {};
             }
-            metric.variantInformations.forEach(function( variantInformation ) {
-              variantInformation.$variant = getVariantByID( variantInformation.variantID );
-            });
           });
         });
     }
@@ -909,9 +935,11 @@ angular.module('upsConsole')
       fetchMetrics( self.currentPage, self.searchString )
         .then(function() {
           $log.debug('refreshed');
-          var isPending = self.metrics.some(function(metric) {
-            return metric.servedVariants < metric.totalVariants;
-          });
+          // is the _last_ push job pending?
+          var isPending = self.metrics[0] && (self.metrics[0].servedVariants < self.metrics[0].totalVariants);
+          // var isPending = self.metrics.some(function(metric) {
+          //   return metric.servedVariants < metric.totalVariants;
+          // });
           if (isPending) {
             if (!refreshInterval) {
               $log.debug('scheduling refresh');
@@ -928,16 +956,7 @@ angular.module('upsConsole')
     // initial load
     refreshUntilAllServed();
 
-    $scope.$on('upsNotificationSent', function() {
-      var timer1 = $timeout(refreshUntilAllServed, 500); // artificial delay - refresh after 0.5sec to ensure server has time to load some batches; prevents situation when totalBatches = 0 for all variants
-      var timer2 = $timeout(refreshUntilAllServed, 3000); // refresh again to be double-sure ;-) note: should be addressed as part of https://issues.jboss.org/browse/AGPUSH-1513
-      // destroy timeouts
-      $scope.$on("$destroy", function() {
-        $log.debug('cancelling refreshUntilAllServed timeouts');
-        $timeout.cancel( timer1 );
-        $timeout.cancel( timer2 );
-      });
-    });
+    $scope.$on('upsNotificationSent', refreshUntilAllServed);
     $scope.$on('$destroy', function () {
       if (refreshInterval) {
         $log.debug('cancelling refreshInterval');
@@ -945,9 +964,14 @@ angular.module('upsConsole')
       }
     });
 
-    $scope.$watch(function() { return self.searchString }, function( searchString ) {
-      self.currentPage = 1;
-      fetchMetrics( self.currentPage, self.searchString );
+    $scope.$watch(function() { 
+      return self.searchString 
+    }, function (newSearchString, oldSearchString) {
+      //ensure that the value has actually changed, to prevent fetchMetrics being called on initial load here
+      if (newSearchString !== oldSearchString) {
+        self.currentPage = 1;
+        fetchMetrics(self.currentPage, self.newSearchString);
+      }
     });
 
   });
@@ -988,7 +1012,7 @@ angular.module('upsConsole')
           ];
           angular.forEach(self.metrics, function (pushMessage) {
             pushMessage.message = JSON.parse(pushMessage.rawJsonMessage);
-            self.performance[0].push(pushMessage.totalReceivers);
+            self.performance[0].push(0);
             self.performance[1].push(pushMessage.appOpenCounter);
           });
 
@@ -1004,8 +1028,6 @@ angular.module('upsConsole')
         });
     }
 
-    updateAnalytics();
-
     $scope.$on('upsNotificationSent', function( pushData, app ) {
       updateAnalytics();
     });
@@ -1022,8 +1044,6 @@ angular.module('upsConsole')
       switch(variant.type) {
         case 'adm': return 'Amazon';
         case 'ios': return 'iOS';
-        case 'simplePush': return 'SimplePush';
-        case 'windows_mpns': return 'Windows';
         case 'windows_wns': return 'Windows';
         case 'android': return 'Android';
         default: return variant.type;
@@ -1555,9 +1575,6 @@ angular.module('upsConsole').factory('variantModal', function ($modal, $q, varia
     case 'android':
       properties = properties.concat(['projectNumber', 'googleKey']);
       break;
-    case 'simplePush':
-      properties = properties.concat([]);
-      break;
     case 'ios':
       if (variant.certificates && variant.certificates.length) {
         variant.certificate = variant.certificates[0];
@@ -1572,10 +1589,6 @@ angular.module('upsConsole').factory('variantModal', function ($modal, $q, varia
       result.protocolType = 'wns';
       properties = properties.concat(['sid', 'clientSecret']);
       break;
-    case 'windows_mpns':
-      result.protocolType = 'mpns';
-      properties = properties.concat([]);
-      break;
     case 'adm':
       properties = properties.concat(['clientId', 'clientSecret']);
       break;
@@ -1660,12 +1673,7 @@ var upsServices = angular.module('upsConsole');
 upsServices.factory('pushConfigGenerator', function ($resource, $q, ContextProvider) {
 
 	function cordovaVariantType(variant) {
-		switch (variant.type) {
-		case 'windows_mpns':
-			return 'windows';
-		default:
 			return variant.type;
-		}
 	}
 
 	function variantSpecificConfiguration(variant, config) {
@@ -1845,9 +1853,7 @@ angular.module('upsConsole')
         $scope.typeEnum = {
           android:      { name: 'Android',    snippets: ['android', 'cordova', 'titanium', 'push_config'] },
           ios:          { name: 'iOS',        snippets: ['ios_objc', 'ios_swift', 'cordova', 'titanium', 'push_config']},
-          windows_mpns: { name: 'Windows',    snippets: ['dotnet', 'cordova', 'push_config'] },
           windows_wns:  { name: 'Windows',    snippets: ['dotnet', 'cordova', 'push_config'] },
-          simplePush:   { name: 'SimplePush', snippets: ['cordova', 'push_config'] },
           adm:          { name: 'ADM',        snippets: ['adm'] }
         };
         $scope.state = {
@@ -1873,12 +1879,7 @@ angular.module('upsConsole')
           }, 1000);
         };
         $scope.cordovaVariantType = (function() {
-          switch ($scope.variant.type) {
-          case 'windows_mpns':
-            return 'windows';
-          default:
             return $scope.variant.type;
-          }
         })();
         $scope.senderID = $scope.variant.type === 'android' ? $scope.variant.projectNumber : null;
         $scope.$watch('variant.secret', function() {
@@ -1894,8 +1895,8 @@ angular.module('upsConsole')
         url: 'snippets/senders/sender.java',
         show: true,
         text: {
-          before: '<p>First you need to add <code>unifiedpush-java-client.jar</code> as a <a ups-doc="sender-downloads-java">dependency to your Java project</a>.</p>' +
-                  '<p>Then let\'s use following snippet in your Java code to enable push notification sending.</p>',
+          before: '<p>First add <code>unifiedpush-java-client.jar</code> as a <a ups-doc="sender-downloads-java">dependency to your Java project</a>.</p>' +
+                  '<p>Then use the following snippet in your Java code to enable push notification sending.</p>',
           after:  '<p>Read more on the details of the <a ups-doc="sender-api-java">Java UPS Sender API in documentation</a>.</p>' +
                   '<p>If you have questions about this process, <a ups-doc="sender-step-by-step-java">visit the documentation for full step by step explanation</a>.</p>'
         }
@@ -1904,8 +1905,8 @@ angular.module('upsConsole')
         url: 'snippets/senders/sender-nodejs.js',
         show: true,
         text: {
-          before: '<p>First you need to download add <code>unifiedpush-node-sender</code> as a <a ups-doc="sender-downloads-nodejs">dependency to your project</a>.</p>' +
-                  '<p>Then let\'s use following snippet in your Node.js code to enable push notification sending.</p>',
+          before: '<p>First download add <code>unifiedpush-node-sender</code> as a <a ups-doc="sender-downloads-nodejs">dependency to your project</a>.</p>' +
+                  '<p>Then use the following snippet in your Node.js code to enable push notification sending.</p>',
           after:  '<p>Read more on the details of the <a ups-doc="sender-api-nodejs">Node.js UPS Sender API in documentation</a>.</p>'
         }
       },
@@ -1913,9 +1914,9 @@ angular.module('upsConsole')
         url: 'snippets/senders/sender-curl.sh',
         show: true,
         text: {
-          before: '<p>If none from the official client libs doesn\'t suit you or you just want to simply try out the notification sending, you can use REST API directly.</p>' +
-                  '<p>Run following <code>curl</code> command in the shell to send notification to UPS server.</p>',
-          after:  '<p>Read more on the details of the <a ups-doc="sender-api-rest">UPS REST Sender API in documentation</a>.</p>'
+          before: '<p>If none of the official client libs suit you or you just want to simply try out the notification sending, you can use the REST API directly.</p>' +
+                  '<p>Run the following <code>curl</code> command in a shell to send a notification to UPS server.</p>',
+          after:  '<p>Read more about the <a ups-doc="sender-api-rest">UPS REST Sender API in the documentation</a>.</p>'
         }
       }
     };
@@ -2208,7 +2209,9 @@ var upsServices = angular.module('upsConsole');
 
 upsServices.factory('messageSenderEndpoint', function ($resource, apiPrefix) {
   return function ( applicationID, masterSecret ) {
-    return $resource( apiPrefix + 'rest/sender', {}, {
+    var url = apiPrefix + 'rest/sender';
+    var paramDefaults = {};
+    var actions = {
       send: {
         method: 'POST',
         headers: {
@@ -2216,7 +2219,9 @@ upsServices.factory('messageSenderEndpoint', function ($resource, apiPrefix) {
           'Authorization': 'Basic ' + btoa(applicationID + ':' + masterSecret)
         }
       }
-    });
+    };
+
+    return $resource(url, paramDefaults, actions);
   };
 });
 
@@ -2239,18 +2244,9 @@ upsServices.factory('metricsEndpoint', function ($resource, $q, apiPrefix) {
       var deferred = $q.defer();
       this.application({id: applicationId, page: pageNo - 1, per_page: perPage, sort:'desc', search: searchString}, function (data, responseHeaders) {
         angular.forEach(data, function (metric) {
-          metric.totalVariants = metric.variantInformations.length;
+          metric.totalVariants = 0;
           metric.servedVariants = 0;
           metric.totalReceivers = 0;
-          angular.forEach(metric.variantInformations, function (variantMetric) {
-            metric.totalReceivers += variantMetric.receivers;
-            if (!variantMetric.deliveryStatus) {
-              metric.deliveryFailed = true;
-            }
-            if (variantMetric.servedBatches === variantMetric.totalBatches) {
-              metric.servedVariants += 1;
-            }
-          });
         });
         deferred.resolve({
           totalItems: parseInt(responseHeaders('total'), 10),
